package com.ruoyi.bar.service;

import java.util.List;
import com.ruoyi.bar.domain.WyBarRoleMenu;

/**
 * 品牌方角色和菜单关联Service接口
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
public interface IWyBarRoleMenuService 
{
    /**
     * 查询品牌方角色和菜单关联
     * 
     * @param roleId 品牌方角色和菜单关联主键
     * @return 品牌方角色和菜单关联
     */
    public WyBarRoleMenu selectWyBarRoleMenuByRoleId(Long roleId);

    /**
     * 查询品牌方角色和菜单关联列表
     * 
     * @param wyBarRoleMenu 品牌方角色和菜单关联
     * @return 品牌方角色和菜单关联集合
     */
    public List<WyBarRoleMenu> selectWyBarRoleMenuList(WyBarRoleMenu wyBarRoleMenu);

    /**
     * 新增品牌方角色和菜单关联
     * 
     * @param wyBarRoleMenu 品牌方角色和菜单关联
     * @return 结果
     */
    public int insertWyBarRoleMenu(WyBarRoleMenu wyBarRoleMenu);

    /**
     * 修改品牌方角色和菜单关联
     * 
     * @param wyBarRoleMenu 品牌方角色和菜单关联
     * @return 结果
     */
    public int updateWyBarRoleMenu(WyBarRoleMenu wyBarRoleMenu);

    /**
     * 批量删除品牌方角色和菜单关联
     * 
     * @param roleIds 需要删除的品牌方角色和菜单关联主键集合
     * @return 结果
     */
    public int deleteWyBarRoleMenuByRoleIds(Long[] roleIds);

    /**
     * 删除品牌方角色和菜单关联信息
     * 
     * @param roleId 品牌方角色和菜单关联主键
     * @return 结果
     */
    public int deleteWyBarRoleMenuByRoleId(Long roleId);
}
